// Keep track of active tabs
let activeTabStates = new Map();

chrome.action.onClicked.addListener(async (tab) => {
    try {
        console.log('Extension icon clicked');
        
        // Toggle the state for this tab
        const isCurrentlyActive = activeTabStates.get(tab.id) || false;
        const newState = !isCurrentlyActive;
        activeTabStates.set(tab.id, newState);
        console.log('New state:', newState);
        
        // Update icon based on new state
        const iconPath = newState ? {
            16: "icons/icon-green-16.png",
            32: "icons/icon-green-32.png",
            48: "icons/icon-green-48.png",
            128: "icons/icon-green-128.png"
        } : {
            16: "icons/icon-gray-16.png",
            32: "icons/icon-gray-32.png",
            48: "icons/icon-gray-48.png",
            128: "icons/icon-gray-128.png"
        };
        
        await chrome.action.setIcon({
            tabId: tab.id,
            path: iconPath
        });
        
        // Execute the initialization and toggle function
        await chrome.scripting.executeScript({
            target: { tabId: tab.id },
            func: (shouldBeActive) => {
                console.log('Executing script with state:', shouldBeActive);
                
                // Check if speech recognition is available
                if (!window.webkitSpeechRecognition) {
                    console.error('Speech Recognition API not available');
                    return;
                }

                // Initialize if not already done
                if (!window.languagePolice) {
                    console.log('Initializing Language Police');
                    
                    window.languagePolice = {
                        recognition: new webkitSpeechRecognition(),
                        isActive: false,
                        warningElement: document.createElement('div')
                    };

                    // Set up warning element
                    const warning = window.languagePolice.warningElement;
                    warning.style.cssText = `
                        position: fixed;
                        top: 20px;
                        right: 20px;
                        background-color: #ff4444;
                        color: white;
                        padding: 15px;
                        border-radius: 5px;
                        z-index: 10000;
                        display: none;
                        font-size: 18px;
                        font-weight: bold;
                        box-shadow: 0 2px 5px rgba(0,0,0,0.2);
                    `;
                    document.body.appendChild(warning);

                    // Set up recognition
                    const recognition = window.languagePolice.recognition;
                    recognition.continuous = true;
                    recognition.interimResults = true;
                    recognition.lang = 'en-US';

                    recognition.onstart = () => {
                        console.log('Speech recognition started');
                    };

                    recognition.onend = () => {
                        console.log('Speech recognition ended');
                        // Restart if still active
                        if (window.languagePolice.isActive) {
                            setTimeout(() => recognition.start(), 1000);
                        }
                    };

                    recognition.onerror = (event) => {
                        console.error('Recognition error:', event.error);
                    };

                    recognition.onresult = (event) => {
                        const transcript = Array.from(event.results)
                            .map(result => result[0].transcript.toLowerCase())
                            .join(' ');
                        
                        console.log('Transcript:', transcript);
                        
                        // Get last three words
                        const words = transcript.trim().split(/\s+/);
                        const lastThreeWords = words.slice(-1);
                        console.log('Last three words:', lastThreeWords);

                        // Check for bad words
                        const badWords = [
                            'fuck', 'fucking', 'fucked', 'fucker', 'fucks', 'motherfucker', 'motherfucking',
                            'shit', 'shitting', 'shitty', 'shat', 'bullshit', 'horseshit',
                            'damn', 'damnit', 'damned', 'goddamn', 'goddamnit', 'goddarn',
                            'ass', 'asshole', 'asses', 'jackass', 'dumbass', 'badass',
                            'bitch', 'bitching', 'bitches', 'sonofabitch',
                            'crap', 'crappy', 'crapped',
                            'hell', 'hellish', 'what the hell', 'to hell',
                            'piss', 'pissed', 'pissing', 'pisses', 'piss-off',
                            'bastard', 'bastards',
                            'dick', 'dickhead', 'dicking', 'dicks', 'dickwad', 'dickweed',
                            'cock', 'cocksucker', 'cocky', 'cocked',
                            'slut', 'slutty', 'sluts',
                            'whore', 'whores', 'whoring',
                            'jerk', 'jerking', 'jerked',
                            'prick', 'pricks', 'pricking',
                            'freak', 'freaking', 'freaked',
                            'douche', 'douchebag', 'douches',
                            'moron', 'morons',
                            'idiot', 'idiots',
                            'imbecile', 'imbeciles',
                            'scum', 'scumbag', 'scumbags',
                            'retard', 'retarded',
                            'screw', 'screwing', 'screwed', 'screws', 'screw-up',
                            'loser', 'losers',
                            'suck', 'sucking', 'sucker', 'sucked', 'sucks'
                        ];
                        badWords.forEach(word => {
                            if (lastThreeWords.includes(word)) {
                                console.log('Bad word detected:', word);
                                warning.textContent = "Language!";
                                warning.style.display = 'block';
                                setTimeout(() => {
                                    warning.style.display = 'none';
                                }, 2000);
                            }
                        });
                    };
                }

                // Toggle recognition
                if (shouldBeActive && !window.languagePolice.isActive) {
                    console.log('Starting recognition');
                    window.languagePolice.isActive = true;
                    window.languagePolice.recognition.start();
                } else if (!shouldBeActive && window.languagePolice.isActive) {
                    console.log('Stopping recognition');
                    window.languagePolice.isActive = false;
                    window.languagePolice.recognition.stop();
                }
            },
            args: [newState]
        });
        
    } catch (err) {
        console.error('Error:', err);
    }
});

// Clean up when tabs are closed
chrome.tabs.onRemoved.addListener((tabId) => {
    activeTabStates.delete(tabId);
});

chrome.runtime.onInstalled.addListener(() => {
    console.log('Language Police extension installed');
}); 